package MFFloat;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFFloat;
our $SField = new SFFloat;

1;
__END__
